@@ -1,11 +1,15 @@
 //! Parses blocks inside a Matroska file.
-use std::collections::VecDeque;
-use std::convert::{TryFrom, TryInto};
-use std::io::{Read, Seek};
-use std::ops::Add;
+use std::{
+    collections::VecDeque,
+    convert::{TryFrom, TryInto},
+    io::{Read, Seek},
+    ops::Add,
+};
 
-use crate::ebml::{parse_variable_i64, parse_variable_u64};
-use crate::Result;
+use crate::{
+    ebml::{parse_variable_i64, parse_variable_u64},
+    Result,
+};
 
 #[derive(Clone, Copy, Debug, Eq, PartialEq)]
 enum Lacing {
@@ -40,7 +44,7 @@ pub(crate) fn probe_block_timestamp<R: Read + Seek>(
     r: &mut R,
     cluster_timestamp: u64,
 ) -> Result<u64> {
-    let _ = parse_variable_u64(r)?;
+    parse_variable_u64(r)?;
     let timestamp = parse_timestamp(r, cluster_timestamp)?;
 
     Ok(timestamp)
