@@ -1,6 +1,5 @@
 #![warn(missing_docs)]
 #![deny(unsafe_code)]
-#![deny(unused_results)]
 #![deny(clippy::as_conversions)]
 #![deny(clippy::panic)]
 #![deny(clippy::unwrap_used)]
@@ -25,11 +24,13 @@
 //! }
 //! ```
 
-use std::collections::{HashMap, VecDeque};
-use std::convert::TryInto;
-use std::error::Error;
-use std::io::{Read, Seek, SeekFrom};
-use std::num::NonZeroU64;
+use std::{
+    collections::{HashMap, VecDeque},
+    convert::TryInto,
+    error::Error,
+    io::{Read, Seek, SeekFrom},
+    num::NonZeroU64,
+};
 
 use ebml::{
     collect_children, expect_master, find_bool_or, find_custom_type, find_float_or, find_nonzero,
@@ -43,8 +44,10 @@ use element_id::ID_TO_ELEMENT_ID;
 pub use enums::*;
 pub use error::DemuxError;
 
-use crate::block::{parse_laced_frames, probe_block_timestamp, LacedFrame};
-use crate::ebml::{parse_child, try_find_bool};
+use crate::{
+    block::{parse_laced_frames, probe_block_timestamp, LacedFrame},
+    ebml::{parse_child, try_find_bool},
+};
 
 mod block;
 mod ebml;
@@ -78,6 +81,15 @@ pub struct Frame {
     pub is_discardable: Option<bool>,
 }
 
+impl From<Vec<u8>> for Frame {
+    fn from(data: Vec<u8>) -> Self {
+        Self {
+            data,
+            ..Frame::default()
+        }
+    }
+}
+
 /// The EBML header of the file.
 #[derive(Clone, Debug)]
 pub struct EbmlHeader {
@@ -838,22 +850,22 @@ impl MasteringMetadata {
 
     /// Blue X chromaticity coordinate, as defined by CIE 1931.
     pub fn primary_b_chromaticity_x(&self) -> Option<f64> {
-        self.primary_g_chromaticity_x
+        self.primary_b_chromaticity_x
     }
 
     /// Blue Y chromaticity coordinate, as defined by CIE 1931.
     pub fn primary_b_chromaticity_y(&self) -> Option<f64> {
-        self.primary_g_chromaticity_y
+        self.primary_b_chromaticity_y
     }
 
     /// White X chromaticity coordinate, as defined by CIE 1931.
     pub fn white_point_chromaticity_x(&self) -> Option<f64> {
-        self.primary_g_chromaticity_x
+        self.white_point_chromaticity_x
     }
 
     /// White Y chromaticity coordinate, as defined by CIE 1931.
     pub fn white_point_chromaticity_y(&self) -> Option<f64> {
-        self.primary_g_chromaticity_y
+        self.white_point_chromaticity_y
     }
 
     /// Maximum luminance. Represented in candelas per square meter (cd/m^2^).
@@ -1191,7 +1203,7 @@ impl Tag {
 #[derive(Clone, Debug)]
 pub struct Targets {
     target_type_value: Option<u64>,
-    target_type: Option<String>,
+    _target_type: Option<String>,
     tag_track_uid: Option<u64>,
 }
 
@@ -1205,7 +1217,7 @@ impl<R: Read + Seek> ParsableElement<R> for Targets {
 
         Ok(Self {
             target_type_value,
-            target_type,
+            _target_type: target_type,
             tag_track_uid,
         })
     }
@@ -1334,11 +1346,11 @@ impl<R: Read + Seek> ParsableElement<R> for CuePoint {
 /// Contain positions for different tracks corresponding to the timestamp.
 #[derive(Clone, Debug)]
 struct CueTrackPositions {
-    track: u64,
+    _track: u64,
     cluster_position: u64,
     relative_position: Option<u64>,
-    duration: Option<u64>,
-    block_number: Option<u64>,
+    _duration: Option<u64>,
+    _block_number: Option<u64>,
 }
 
 impl<R: Read + Seek> ParsableElement<R> for CueTrackPositions {
@@ -1352,11 +1364,11 @@ impl<R: Read + Seek> ParsableElement<R> for CueTrackPositions {
         let block_number = try_find_unsigned(fields, ElementId::CueBlockNumber)?;
 
         Ok(Self {
-            track,
+            _track: track,
             cluster_position,
             relative_position,
-            duration,
-            block_number,
+            _duration: duration,
+            _block_number: block_number,
         })
     }
 }
@@ -1513,7 +1525,7 @@ impl<R: Read + Seek> MatroskaFile<R> {
                             size: block_size,
                         } = element_data
                         {
-                            let _ = self.file.seek(SeekFrom::Start(header_start))?;
+                            self.file.seek(SeekFrom::Start(header_start))?;
 
                             parse_laced_frames(
                                 &mut self.file,
@@ -1523,7 +1535,7 @@ impl<R: Read + Seek> MatroskaFile<R> {
                                 header_start,
                                 element_id == ElementId::SimpleBlock,
                             )?;
-                            let _ = self.try_pop_frame(frame)?;
+                            self.try_pop_frame(frame)?;
 
                             Ok(true)
                         } else {
@@ -1585,14 +1597,14 @@ impl<R: Read + Seek> MatroskaFile<R> {
 
         let target_offset = self.seek_broad_phase(seek_timestamp, cluster_start)?;
 
-        let _ = self.file.seek(SeekFrom::Start(target_offset));
+        self.file.seek(SeekFrom::Start(target_offset))?;
 
         self.seek_narrow_phase(seek_timestamp)
     }
 
     fn enter_data_location(&mut self, element_data: &ElementData) -> Result<()> {
         if let ElementData::Location { offset, .. } = element_data {
-            let _ = self.file.seek(SeekFrom::Start(*offset))?;
+            self.file.seek(SeekFrom::Start(*offset))?;
             Ok(())
         } else {
             Err(DemuxError::UnexpectedDataType)
@@ -1628,7 +1640,7 @@ impl<R: Read + Seek> MatroskaFile<R> {
         let mut current_cluster_offset = 0;
         let mut next_cluster_offset = 0;
 
-        let _ = self.file.seek(SeekFrom::Start(cluster_start));
+        self.file.seek(SeekFrom::Start(cluster_start))?;
 
         loop {
             match next_element(&mut self.file) {
@@ -1640,7 +1652,7 @@ impl<R: Read + Seek> MatroskaFile<R> {
                             if size == u64::MAX {
                                 return Ok(cluster_start);
                             }
-                            let _ = self.file.seek(SeekFrom::Start(offset))?;
+                            self.file.seek(SeekFrom::Start(offset))?;
                             last_cluster_offset = current_cluster_offset;
                             current_cluster_offset = offset;
                             next_cluster_offset = offset + size;
@@ -1653,7 +1665,7 @@ impl<R: Read + Seek> MatroskaFile<R> {
                         if let ElementData::Unsigned(timestamp) = element_data {
                             match timestamp {
                                 t if t < seek_timestamp => {
-                                    let _ = self.file.seek(SeekFrom::Start(next_cluster_offset))?;
+                                    self.file.seek(SeekFrom::Start(next_cluster_offset))?;
                                 }
                                 t if t > seek_timestamp => {
                                     return Ok(last_cluster_offset);
@@ -1702,18 +1714,18 @@ impl<R: Read + Seek> MatroskaFile<R> {
                     // Parse the block data.
                     ElementId::SimpleBlock | ElementId::Block => {
                         if let ElementData::Location { offset, size } = element_data {
-                            let _ = self.file.seek(SeekFrom::Start(offset))?;
+                            self.file.seek(SeekFrom::Start(offset))?;
                             let timestamp =
                                 probe_block_timestamp(&mut self.file, self.cluster_timestamp)?;
 
                             match timestamp {
                                 t if t < seek_timestamp => {
                                     // Jump to the next element.
-                                    let _ = self.file.seek(SeekFrom::Start(offset + size))?;
+                                    self.file.seek(SeekFrom::Start(offset + size))?;
                                 }
                                 _ => {
                                     // We found the first element after the seeked timestamp.
-                                    let _ = self.file.seek(SeekFrom::Start(position))?;
+                                    self.file.seek(SeekFrom::Start(position))?;
                                     return Ok(());
                                 }
                             }
@@ -1791,8 +1803,7 @@ fn parse_seek_head<R: Read + Seek>(
                 if let ElementData::Location { offset, size } = entry_data {
                     let seek_fields = collect_children(&mut file, *offset, *size)?;
                     if let Ok(seek_entry) = SeekEntry::new(&mut file, &seek_fields) {
-                        let _ = seek_head
-                            .insert(seek_entry.id, segment_data_offset + seek_entry.offset);
+                        seek_head.insert(seek_entry.id, segment_data_offset + seek_entry.offset);
                     }
                 }
             }
@@ -1828,7 +1839,7 @@ fn build_seek_head<R: Read + Seek>(
     segment_data_offset: u64,
     seek_head: &mut HashMap<ElementId, u64>,
 ) -> Result<()> {
-    let _ = r.seek(SeekFrom::Start(segment_data_offset))?;
+    r.seek(SeekFrom::Start(segment_data_offset))?;
     loop {
         let position = r.stream_position()?;
         match next_element(r) {
@@ -1844,7 +1855,7 @@ fn build_seek_head<R: Read + Seek>(
                     if element_id != ElementId::Cluster
                         || !seek_head.contains_key(&ElementId::Cluster)
                     {
-                        let _ = seek_head.insert(element_id, position);
+                        seek_head.insert(element_id, position);
                     }
                 }
             }
@@ -1869,7 +1880,7 @@ fn find_first_cluster_offset<R: Read + Seek>(
         return Err(DemuxError::CantFindCluster);
     };
 
-    let _ = r.seek(SeekFrom::Start(tracks_offset + tracks_size))?;
+    r.seek(SeekFrom::Start(tracks_offset + tracks_size))?;
     loop {
         let position = r.stream_position()?;
 
@@ -1877,7 +1888,7 @@ fn find_first_cluster_offset<R: Read + Seek>(
             Ok((element_id, element_data)) => {
                 if let ElementId::Cluster = element_id {
                     if let ElementData::Location { .. } = element_data {
-                        let _ = seek_head.insert(ElementId::Cluster, position);
+                        seek_head.insert(ElementId::Cluster, position);
                         break;
                     } else {
                         return Err(DemuxError::UnexpectedDataType);
@@ -1961,7 +1972,7 @@ fn seek_to_first_cluster<R: Read + Seek>(
     seek_head: &HashMap<ElementId, u64>,
 ) -> Result<()> {
     if let Some(offset) = seek_head.get(&ElementId::Cluster) {
-        let _ = r.seek(SeekFrom::Start(*offset))?;
+        r.seek(SeekFrom::Start(*offset))?;
         Ok(())
     } else {
         Err(DemuxError::ElementNotFound(ElementId::Cluster))
